def print_lol(item_list,level=0):
    for each_item in item_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end='')
            print (each_item)
        

            



from distutils.core import setup

setup(
    name = 'janetlist', 
    version  = '1.1.2',
    py_modules = ['janetlist'],
    author = 'ZhangPeng',
    author_email = '444327149@qq.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )


